NodePiece
=========

.. currentmodule:: pykeen.models

.. autoclass:: NodePiece
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~NodePiece.hpo_default

   .. rubric:: Attributes Documentation

   .. autoattribute:: hpo_default
